@@ -19,21 +19,21 @@
  * ----------------------------------------------------------------------
  */
 
-//! \brief Forward declaration for RGBRemapper
+//! \brief Forward declaration for Remapper
 
 #ifndef PFS_RGBREMAPPER_FWD_H
 #define PFS_RGBREMAPPER_FWD_H
 
-enum RGBMappingType
-{
-    MAP_LINEAR      = 0,
-    MAP_GAMMA1_4    = 1,
-    MAP_GAMMA1_8    = 2,
-    MAP_GAMMA2_2    = 3,
-    MAP_GAMMA2_6    = 4,
+enum RGBMappingType {
+    MAP_LINEAR = 0,
+    MAP_GAMMA1_4 = 1,
+    MAP_GAMMA1_8 = 2,
+    MAP_GAMMA2_2 = 3,
+    MAP_GAMMA2_6 = 4,
     MAP_LOGARITHMIC = 5
 };
 
-class RGBRemapper;
+template <typename TypeOut>
+class Remapper;
 
-#endif // PFS_RGBREMAPPER_FWD_H
+#endif  // PFS_RGBREMAPPER_FWD_H
